@@ -8,9 +8,13 @@ if (!is.R()) {
   }
 }
 
-"CRS" <- function(projargs=NA_character_, doCheckCRSArgs=TRUE) {
+"CRS" <- function(projargs=NA_character_, doCheckCRSArgs=TRUE,
+    SRS_string=NULL) {
 # cautious change BDR 150424
-    if (!is.na(projargs) && !nzchar(projargs)) projargs <- NA_character_
+# trap NULL too 200225
+    if (is.null(projargs))
+        warning("CRS: projargs should not be NULL; set to NA")
+    if ((is.null(projargs)) || (!is.na(projargs) && !nzchar(projargs))) projargs <- NA_character_
 # condition added 140301
     stopifnot(is.logical(doCheckCRSArgs))
     stopifnot(length(doCheckCRSArgs) == 1L)
@@ -28,28 +32,46 @@ if (!is.R()) {
             warning("'lonlat' changed to 'longlat': ", projargs)
         }
     }    
-    if (is.na(projargs))
+    if (is.na(projargs)) {
         uprojargs <- projargs
-    else uprojargs <- paste(unique(unlist(strsplit(projargs, " "))), 
+    } else {
+        uprojargs <- paste(unique(unlist(strsplit(projargs, " "))), 
 	collapse=" ")
-    if (length(grep("= ", uprojargs)) != 0)
-	stop(paste("No spaces permitted in PROJ4 argument-value pairs:", 
-	    uprojargs))
-    if (length(grep(" [:alnum:]", uprojargs)) != 0)
-	stop(paste("PROJ4 argument-value pairs must begin with +:", 
-	    uprojargs))
+        if (length(grep("= ", uprojargs)) != 0)
+	    stop(paste("No spaces permitted in PROJ4 argument-value pairs:", 
+	        uprojargs))
+        if (length(grep(" [:alnum:]", uprojargs)) != 0)
+	    stop(paste("PROJ4 argument-value pairs must begin with +:", 
+	        uprojargs))
+    }
 #    if (length(grep("rgdal", search()) > 0) &&
 #      (sessionInfo()$otherPkgs$rgdal$Version > "0.4-2")) {
 # sessionInfo()/read.dcf() problem in loop 080307
-    if (doCheckCRSArgs) {
-      if (!is.na(uprojargs) && requireNamespace("rgdal", quietly = TRUE)) {
-        res <- rgdal::checkCRSArgs(uprojargs)
-        if (!res[[1]]) 
-            stop(res[[2]])
-        uprojargs <- res[[2]]
-      }
+    comm <- NULL
+    if (!is.na(uprojargs) || !is.null(SRS_string)) {
+        if (doCheckCRSArgs && requireNamespace("rgdal", quietly = TRUE)) {
+            if ((length(grep("ob_tran", uprojargs)) > 0L) ||
+                packageVersion("rgdal") < "1.5.1") {
+                res <- rgdal::checkCRSArgs(uprojargs)
+                if (!res[[1]]) stop(res[[2]])
+                uprojargs <- res[[2]]
+            } else if (packageVersion("rgdal") >= "1.5.1") {
+                if (rgdal::new_proj_and_gdal()) {
+                    res <- rgdal::checkCRSArgs_ng(uprojargs=uprojargs,
+                        SRS_string=SRS_string)
+                    if (!res[[1]]) stop(res[[2]])
+                    uprojargs <- res[[2]]
+                    comm <- res[[3]]
+                } else { #stop("rgdal version mismatch")
+                    res <- rgdal::checkCRSArgs(uprojargs)
+                    if (!res[[1]]) stop(res[[2]])
+                    uprojargs <- res[[2]]
+                }
+            } else stop("rgdal version mismatch")
+        }
     }
     res <- new("CRS", projargs=uprojargs)
+    if (!is.null(comm)) comment(res) <- comm
     res
 }
 
