@@ -21,7 +21,8 @@ SpatialPolygons <- function(Srl, pO, proj4string=CRS(as.character(NA))) {
 	res <- .Call(SpatialPolygons_c, Srl, pO, proj4string)
 	validObject(res)
 # 120416 add top-level comment to reduce comment checking
-	cSr <- as.character(any(sapply(slot(res, "polygons"),
+	cSr <- as.character(all(sapply(slot(res, "polygons"),
+# 180201 change any to all after NULL comment found; https://github.com/r-spatial/sf/issues/636
             function(x) !is.null(comment(x))), na.rm=TRUE))
 	comment(res) <- cSr
 	res
@@ -34,6 +35,13 @@ Polygon <- function(coords, hole=as.logical(NA)) {
 	if (ncol(coords) != 2) stop("coords must be a two-column matrix")
 # RSB 091203
         n <- dim(coords)[1]
+        if (n < 4L) {
+            warning("less than 4 coordinates in polygon")
+            if (n == 1L) coords <- rbind(coords, coords, coords, coords)
+            else if (n == 2L) coords <- rbind(coords, coords[1,], coords[1,])
+            else if (n == 3L) coords <- rbind(coords, coords[1,])
+            n <- dim(coords)[1]
+        }
         stopifnot(is.logical(hole))
         ihole <- as.integer(hole)
 # RSB 100126 fixing hole assumption
